intelmq.bots.outputs.mongodb package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.outputs.mongodb package

## Submodules

## intelmq.bots.outputs.mongodb.output module

pymongo library automatically tries to reconnect if connection has been lost.

`intelmq.bots.outputs.mongodb.output.` `BOT`

  alias of `intelmq.bots.outputs.mongodb.output.MongoDBOutputBot`

class `intelmq.bots.outputs.mongodb.output.` `MongoDBOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Send events to a MongoDB database

  `collection` = None
  `connect`()
  `database` = None
  `db_pass` = None
  `db_user` = None
  `hierarchical_output`: bool = False
  `host`: str = 'localhost'
  `init`()
  `password` = None
  `port`: int = 27017
  `process`()
  `replacement_char` = '_'
  `shutdown`()
  `username` = None

## Module contents